@@ -28,7 +28,7 @@ void usage_import(){
 
 void usage_export(){
     cout << "Usage:" << endl;
-    cout << "\t--operation export --calendar CAL_NAME [--file FILE_NAME]" << endl;
+    cout << "\t--operation export --calendar CAL_NAME [--file FILE_NAME] [--quiet]" << endl;
     cout << "\tDefaults to CAL_NAME.ics if no FILE_NAME given" << endl;
 }
 
@@ -504,7 +504,7 @@ bool do_operation_tasks_clear_done(const QStringList args){
     for (unsigned int i=0; i<tasks.size(); i++){
         CTodo *task = tasks.at(i);
 
-        if(task->getCompleted() > 0){
+        if(task->getStatus() == 1){
             cal->deleteTodo(task->getId(),errcode);
             if(errcode != CALENDAR_OPERATION_SUCCESSFUL){
                 cerror++;
@@ -587,7 +587,7 @@ bool do_operation_tasks_bump_today(const QStringList args){
         CTodo *task = tasks.at(i);
 
         //if the task has not been completed yet, check if it was due yesterday
-        if(task->getCompleted() < 1){
+        if(task->getStatus() == 0){
 
             QDateTime qdt_due;
             qdt_due.setTime_t(task->getDue());
