@@ -8,11 +8,13 @@
 
 #include <functions.h>
 
+void log(string msg, int level, bool newline); //declaration for global log method
+
 using namespace std;
 
 QStringList args;
 CMulticalendar *mcalendar = 0;
-
+int _loglevel_ = 1; //default log level. 0 is same as --quiet
 
 int main(int argc, char *argv[])
 {
@@ -43,14 +45,29 @@ int main(int argc, char *argv[])
 
         return -1;
     }
-    //cout << "operation is:" << operation.toLocal8Bit().constData() << endl;
+
+    if(parse_cmd_arg(args,ARG_QUIET)){
+        _loglevel_ = 0;
+    }
+
     ok = do_operation(args, operation);
 
     if (!ok){
-        cout << "Program failure" << endl;
+        cerr << "Program failure" << endl;
         return -1;
     }
 
     //return a.exec();
     return 0;
 }
+
+void log(string msg, int level, bool newline){
+    //print a message to stdout based on the logging level
+    if (level <= _loglevel_){
+        cout << msg;
+        if(newline){
+            cout << endl;
+        }
+    }
+
+}
